.. see also /docs/dev/shared.rst
.. |flash|  image:: /../docs/shared/images/buttons/flash.png
.. |insert_old|  image:: /../docs/shared/images/buttons/insert.png
.. |eject|  image:: /../docs/shared/images/buttons/eject.png
.. |search|  image:: /../docs/shared/images/buttons/search.png
.. |refresh|  image:: /../docs/shared/images/buttons/refresh.png
.. |lightning|  image:: https://github.com/lino-framework/lino/blob/master/lino/static/images/mjames/lightning.png?raw=true
.. |delete|  image:: https://github.com/lino-framework/lino/blob/master/lino/static/images/mjames/delete.png?raw=true
.. |insert|  image:: https://github.com/lino-framework/lino/blob/master/lino/static/images/mjames/add.png?raw=true
.. |detail|  image:: https://github.com/lino-framework/lino/blob/master/lino/static/images/mjames/application_form.png?raw=true
